# RobotPy Rev Digit

[![RobotPy - 2024](https://img.shields.io/badge/RobotPy-2024-2ea44f)](https://github.com/robotpy)
[![python](https://img.shields.io/badge/Python-3.11-3776AB.svg?style=flat&logo=python&logoColor=white)](https://www.python.org)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Checked with mypy](http://www.mypy-lang.org/static/mypy_badge.svg)](http://mypy-lang.org/)

A RobotPy module for control of the REV Robotics Digit Board.
Ported from the Java repository: https://github.com/vampjaz/REVDigitBoard

-----

**Table of Contents**

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install robotpy-rev-digit
```

## License

`robotpy-rev-digit` is distributed under the terms of the [GPL-3.0-only](https://spdx.org/licenses/MIT.html) license.
